@@ -1,14 +1,16 @@
 package Scalar::Cmp;
 
-our $DATE = '2018-12-06'; # DATE
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 
 use Scalar::Util qw(looks_like_number);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-07'; # DATE
+our $DIST = 'Scalar-Cmp'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -97,7 +99,7 @@ Scalar::Cmp - Compare two scalars
 
 =head1 VERSION
 
-This document describes version 0.002 of Scalar::Cmp (from Perl distribution Scalar-Cmp), released on 2018-12-06.
+This document describes version 0.003 of Scalar::Cmp (from Perl distribution Scalar-Cmp), released on 2021-09-07.
 
 =head1 SYNOPSIS
 
@@ -121,11 +123,11 @@ This document describes version 0.002 of Scalar::Cmp (from Perl distribution Sca
  say cmpnum_scalar("a", "0");  # => 0, but emit warnings
 
  # cmpstrornum_scalar uses <=> if both scalars look like number, or cmp otherwise
- say cmp_scalar(1, 1);         # => 0
- say cmp_scalar(1, 2);         # => -1
- say cmp_scalar(2, 1);         # => -1
- say cmp_scalar("1.0", 1);     # => 0
- say cmp_scalar("a", "0");     # => 1
+ say cmpstrornum_scalar(1, 1);         # => 0
+ say cmpstrornum_scalar(1, 2);         # => -1
+ say cmpstrornum_scalar(2, 1);         # => -1
+ say cmpstrornum_scalar("1.0", 1);     # => 0
+ say cmpstrornum_scalar("a", "0");     # => 1
 
 =head1 DESCRIPTION
 
@@ -189,6 +191,44 @@ Please visit the project's homepage at L<https://metacpan.org/release/Scalar-Cmp
 
 Source repository is at L<https://github.com/perlancar/perl-Scalar-Cmp>.
 
+=head1 SEE ALSO
+
+The Perl's C<cmp> and C<< <=> >> operators.
+
+L<Data::Cmp> which uses similar comparison rules but recurse into array and hash
+elements.
+
+L<Syntax::Operator::Equ> introduces several operators/functions which also have
+a rule to equate two undefs.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Scalar-Cmp>
@@ -197,22 +237,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-The Perl's C<cmp> and C<< <=> >> operators.
-
-L<Data::Cmp> which uses similar comparison rules but recurse into array and hash
-elements.
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
